summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmprismmemento.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-08-02 19:23:46 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-08-02 19:23:46 +0000
commiteba47f8f0637f451e21348187591e1f1fd58ac74 (patch)
tree448f10b95c656604acc331a3236c1e59bde5c1ad /kpovmodeler/pmprismmemento.cpp
parentc7e8736c69373f48b0401319757c742e8607431a (diff)
downloadtdegraphics-eba47f8f0637f451e21348187591e1f1fd58ac74.tar.gz
tdegraphics-eba47f8f0637f451e21348187591e1f1fd58ac74.zip
TQt conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1158446 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpovmodeler/pmprismmemento.cpp')
-rw-r--r--kpovmodeler/pmprismmemento.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpovmodeler/pmprismmemento.cpp b/kpovmodeler/pmprismmemento.cpp
index 0f50449d..4b24d500 100644
--- a/kpovmodeler/pmprismmemento.cpp
+++ b/kpovmodeler/pmprismmemento.cpp
@@ -27,21 +27,21 @@ PMPrismMemento::~PMPrismMemento( )
{
}
-void PMPrismMemento::setPrismPoints( const QValueList< QValueList<PMVector> >& v )
+void PMPrismMemento::setPrismPoints( const TQValueList< TQValueList<PMVector> >& v )
{
if( !m_bPrismPointsSaved )
{
// Direct assignment does not work with Qt 2.3.x
// The list will be changed later in a graphical
// change because QValueList::detach( ) is called
// too late!
// Copy the list by hand.
- QValueList< QValueList< PMVector > >::ConstIterator sit = v.begin( );
+ TQValueList< TQValueList< PMVector > >::ConstIterator sit = v.begin( );
for( ; sit != v.end( ); ++sit )
{
- QValueList<PMVector> list;
- QValueList<PMVector>::ConstIterator it = ( *sit ).begin( );
+ TQValueList<PMVector> list;
+ TQValueList<PMVector>::ConstIterator it = ( *sit ).begin( );
for( ; it != ( *sit ).end( ); ++it )
list.append( *it );
m_prismPoints.append( list );
@@ -27,21 +27,21 @@ PMPrismMemento::~PMPrismMemento( )
// Direct assignment does not work with Qt 2.3.x
// The list will be changed later in a graphical
- // change because QValueList::detach( ) is called
+ // change because TQValueList::detach( ) is called
// too late!
// Copy the list by hand.